@@ -2,7 +2,7 @@ use core::mem;
 use std::io::{Write, Result};
 
 use crate::{Cast, Endian, Flip};
-use crate::experimental::AsBytes;
+use crate::experimental::AsifBytes;
 #[cfg(doc)] use crate::BE;
 
 
@@ -43,14 +43,14 @@ use crate::experimental::AsBytes;
 /// // Because the UDP header is 8 bytes as defined above,
 /// // only the first 8 bytes of `output2` are filled with data.
 /// let mut output2 = Cursor::new(vec![0_u8; 16]);
-/// let output2_bytes = output2.decastf(&udp_hdr1, BE)?;
+/// let size2 = output2.decastf(&udp_hdr1, BE)?;
 /// let bytes2 = output2.into_inner();
 ///
 /// // `udp_hdr1` should be encoded as following (8 bytes)
 /// let bytes3: [u8; 8] = [0xC3, 0xC9, 0x00, 0x35, 0x00, 0x32, 0x82, 0x3F];
 ///
-/// // Check the results.
-/// assert_eq!(output2_bytes, 8);
+/// // Check the results (bytes2)
+/// assert_eq!(size2, 8);
 /// assert_eq!(&bytes2[0..8], &bytes3[0..8]);
 /// assert_eq!(&bytes2[8..16], &[0_u8; 8]);
 /// # Ok(())
@@ -119,9 +119,9 @@ where
 	T: Cast
     {
 	unsafe {
-	    self.write_all(val_ptr.as_bytes_ref())?;
+	    self.write_all(val_ptr.asif_bytes_ref())?;
 	}
-	Ok(mem::size_of_val(val_ptr))
+	Ok(mem::size_of::<T>())
     }
 
     fn decastf<T>(&mut self, val_ptr: &T, endian: Endian) -> Result<usize>
@@ -140,9 +140,9 @@ where
 	T: Cast
     {
 	unsafe {
-	    self.write_all(slice.as_bytes_ref())?;
+	    self.write_all(slice.asif_bytes_ref())?;
 	}
-	Ok(slice.len())
+	Ok(mem::size_of::<T>() * slice.len())
     }
 
     fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Result<usize>
@@ -155,7 +155,7 @@ where
 	    for elem in slice {
 		self.decast::<T>(&elem.flip_val_swapped())?;
 	    }
-	    Ok(slice.len())
+	    Ok(mem::size_of::<T>() * slice.len())
 	}
     }
 }
